summaryrefslogtreecommitdiffstats
path: root/tests
diff options
context:
space:
mode:
authorMaksymilian Osowski <maxosowski@google.com>2010-09-02 09:33:08 -0700
committerAndroid (Google) Code Review <android-gerrit@google.com>2010-09-02 09:33:08 -0700
commitfddedbf999a57220ed89bbebe9f35e093aa77c2d (patch)
treef415fc0b8ec51131c8dad0187b5d630a8b9d9b12 /tests
parent7e04056ca92d11425732aa3228dad6f0d979b6aa (diff)
parent5f21f5a4a9f240e1c35ab86b2f3a332f0d541cf0 (diff)
downloadframeworks_base-fddedbf999a57220ed89bbebe9f35e093aa77c2d.zip
frameworks_base-fddedbf999a57220ed89bbebe9f35e093aa77c2d.tar.gz
frameworks_base-fddedbf999a57220ed89bbebe9f35e093aa77c2d.tar.bz2
Merge "Updated Summarizer to parse CRASH instead of SKIP."
Diffstat (limited to 'tests')
-rw-r--r--tests/DumpRenderTree2/src/com/android/dumprendertree2/FileFilter.java14
-rw-r--r--tests/DumpRenderTree2/src/com/android/dumprendertree2/TestsListPreloaderThread.java9
2 files changed, 13 insertions, 10 deletions
diff --git a/tests/DumpRenderTree2/src/com/android/dumprendertree2/TestsListPreloaderThread.java b/tests/DumpRenderTree2/src/com/android/dumprendertree2/TestsListPreloaderThread.java
index 9fa2335..c714ec4 100644
--- a/tests/DumpRenderTree2/src/com/android/dumprendertree2/TestsListPreloaderThread.java
+++ b/tests/DumpRenderTree2/src/com/android/dumprendertree2/TestsListPreloaderThread.java
@@ -99,11 +99,14 @@ public class TestsListPreloaderThread extends Thread {
false, false)) {
itemName = new File(testRelativePath).getName();
if (FileFilter.isTestFile(itemName)) {
- if (!mFileFilter.isSkip(testRelativePath)) {
+ /** We chose to skip all the tests that are expected to crash. */
+ if (!mFileFilter.isCrash(testRelativePath)) {
mTestsList.add(testRelativePath);
} else {
- //mSummarizer.addSkippedTest(relativePath);
- /** TODO: Summarizer is now in service - figure out how to send the info */
+ /**
+ * TODO: Summarizer is now in service - figure out how to send the info.
+ * Previously: mSummarizer.addSkippedTest(relativePath);
+ */
}
}
}
diff --git a/tests/DumpRenderTree2/src/com/android/dumprendertree2/FileFilter.java b/tests/DumpRenderTree2/src/com/android/dumprendertree2/FileFilter.java
index 9427719..4ab76e3 100644
--- a/tests/DumpRenderTree2/src/com/android/dumprendertree2/FileFilter.java
+++ b/tests/DumpRenderTree2/src/com/android/dumprendertree2/FileFilter.java
@@ -48,11 +48,11 @@ public class FileFilter {
private static final String HTTP_TESTS_PATH = "http/tests/";
private static final String SSL_PATH = "ssl/";
- private static final String TOKEN_SKIP = "SKIP";
+ private static final String TOKEN_CRASH = "CRASH";
private static final String TOKEN_FAIL = "FAIL";
private static final String TOKEN_SLOW = "SLOW";
- private final Set<String> mSkipList = new HashSet<String>();
+ private final Set<String> mCrashList = new HashSet<String>();
private final Set<String> mFailList = new HashSet<String>();
private final Set<String> mSlowList = new HashSet<String>();
@@ -121,8 +121,8 @@ public class FileFilter {
tokens = new HashSet<String>(Arrays.asList(parts[1].split("\\s", 0)));
/** Chose the right collections to add to */
- if (tokens.contains(TOKEN_SKIP)) {
- mSkipList.add(path);
+ if (tokens.contains(TOKEN_CRASH)) {
+ mCrashList.add(path);
/** If test is on skip list we ignore any further options */
continue;
@@ -151,7 +151,7 @@ public class FileFilter {
}
/**
* Checks if test is supposed to be skipped.
*
* <p>
* Path given should relative within LayoutTests folder, e.g. fast/dom/foo.html
@@ -160,9 +160,9 @@ public class FileFilter {
* - a relative path within LayoutTests folder
* @return if the test is supposed to be skipped
*/
- public boolean isSkip(String testPath) {
+ public boolean isCrash(String testPath) {
for (String prefix : getPrefixes(testPath)) {
- if (mSkipList.contains(prefix)) {
+ if (mCrashList.contains(prefix)) {
return true;
}
}
@@ -151,7 +151,7 @@ public class FileFilter {
}
/**
- * Checks if test is supposed to be skipped.
+ * Checks if test is expected to crash.
*
* <p>